changeset 10:33cbafd41036

add ninja
author ikkun <ikkun@cr.ie.u-ryukyu.ac.jp>
date Fri, 16 Jun 2017 20:10:06 +0900
parents 556456198f52
children 33a4e0db0664
files osc.md sample/CMakeCache.txt sample/CMakeFiles/CMakeOutput.log sample/build.ninja sample/cmake_install.cmake sample/hello sample2/CMakeLists.txt
diffstat 7 files changed, 61 insertions(+), 115 deletions(-) [+]
line wrap: on
line diff
--- a/osc.md	Fri Jun 16 05:31:42 2017 +0900
+++ b/osc.md	Fri Jun 16 20:10:06 2017 +0900
@@ -84,6 +84,9 @@
 - cmake .でMakefileを作成し、make matrixMul.cuでビルドします
 
 # Ninja
+- cmkae に -G Ninjaオプションをつけてninjaのbuildファイルとルールファイルを作成します。
+- ninjaでNinjaによるコンパイルを行います。
+
 
 LLVMの例題もやるのでLLVMの場所も書いておく
 
--- a/sample/CMakeCache.txt	Fri Jun 16 05:31:42 2017 +0900
+++ b/sample/CMakeCache.txt	Fri Jun 16 20:10:06 2017 +0900
@@ -21,9 +21,6 @@
 // CMAKE_C_FLAGS used) Debug Release RelWithDebInfo MinSizeRel.
 CMAKE_BUILD_TYPE:STRING=
 
-//Enable/Disable color output during build.
-CMAKE_COLOR_MAKEFILE:BOOL=ON
-
 //CXX compiler
 CMAKE_CXX_COMPILER:FILEPATH=/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++
 
@@ -89,8 +86,8 @@
 //Path to a program.
 CMAKE_LINKER:FILEPATH=/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld
 
-//Path to a program.
-CMAKE_MAKE_PROGRAM:FILEPATH=/usr/bin/make
+//Program used to build from build.ninja files.
+CMAKE_MAKE_PROGRAM:FILEPATH=/usr/local/bin/ninja
 
 //Flags used by the linker during the creation of modules.
 CMAKE_MODULE_LINKER_FLAGS:STRING=
@@ -200,8 +197,6 @@
 CMAKE_CACHE_MINOR_VERSION:INTERNAL=8
 //Patch version of cmake used to create the current loaded cache
 CMAKE_CACHE_PATCH_VERSION:INTERNAL=2
-//ADVANCED property for variable: CMAKE_COLOR_MAKEFILE
-CMAKE_COLOR_MAKEFILE-ADVANCED:INTERNAL=1
 //Path to CMake executable.
 CMAKE_COMMAND:INTERNAL=/usr/local/Cellar/cmake/3.8.2/bin/cmake
 //Path to cpack program executable.
@@ -232,8 +227,6 @@
 CMAKE_C_FLAGS_RELEASE-ADVANCED:INTERNAL=1
 //ADVANCED property for variable: CMAKE_C_FLAGS_RELWITHDEBINFO
 CMAKE_C_FLAGS_RELWITHDEBINFO-ADVANCED:INTERNAL=1
-//Path to cache edit program executable.
-CMAKE_EDIT_COMMAND:INTERNAL=/usr/local/Cellar/cmake/3.8.2/bin/ccmake
 //Executable file format
 CMAKE_EXECUTABLE_FORMAT:INTERNAL=Unknown
 //ADVANCED property for variable: CMAKE_EXE_LINKER_FLAGS
@@ -251,7 +244,7 @@
 //Name of external makefile project generator.
 CMAKE_EXTRA_GENERATOR:INTERNAL=
 //Name of generator.
-CMAKE_GENERATOR:INTERNAL=Unix Makefiles
+CMAKE_GENERATOR:INTERNAL=Ninja
 //Name of generator platform.
 CMAKE_GENERATOR_PLATFORM:INTERNAL=
 //Name of generator toolset.
--- a/sample/CMakeFiles/CMakeOutput.log	Fri Jun 16 05:31:42 2017 +0900
+++ b/sample/CMakeFiles/CMakeOutput.log	Fri Jun 16 20:10:06 2017 +0900
@@ -28,29 +28,21 @@
 Determining if the C compiler works passed with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_caf4f/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_caf4f.dir/build.make CMakeFiles/cmTC_caf4f.dir/build
-Building C object CMakeFiles/cmTC_caf4f.dir/testCCompiler.c.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -o CMakeFiles/cmTC_caf4f.dir/testCCompiler.c.o   -c /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp/testCCompiler.c
-Linking C executable cmTC_caf4f
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_caf4f.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names   CMakeFiles/cmTC_caf4f.dir/testCCompiler.c.o  -o cmTC_caf4f 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_adae5"
+[1/2] Building C object CMakeFiles/cmTC_adae5.dir/testCCompiler.c.o
+[2/2] Linking C executable cmTC_adae5
 
 
 Detecting C compiler ABI info compiled with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_e7743/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_e7743.dir/build.make CMakeFiles/cmTC_e7743.dir/build
-Building C object CMakeFiles/cmTC_e7743.dir/CMakeCCompilerABI.c.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -o CMakeFiles/cmTC_e7743.dir/CMakeCCompilerABI.c.o   -c /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCCompilerABI.c
-Linking C executable cmTC_e7743
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_e7743.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names  -v -Wl,-v CMakeFiles/cmTC_e7743.dir/CMakeCCompilerABI.c.o  -o cmTC_e7743 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_6d9b4"
+[1/2] Building C object CMakeFiles/cmTC_6d9b4.dir/CMakeCCompilerABI.c.o
+[2/2] Linking C executable cmTC_6d9b4
 Apple LLVM version 7.0.2 (clang-700.1.81)
 Target: x86_64-apple-darwin15.6.0
 Thread model: posix
- "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -dynamic -arch x86_64 -macosx_version_min 10.11.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -o cmTC_e7743 -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_e7743.dir/CMakeCCompilerABI.c.o -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a
+ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -dynamic -arch x86_64 -macosx_version_min 10.11.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -o cmTC_6d9b4 -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_6d9b4.dir/CMakeCCompilerABI.c.o -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a
 @(#)PROGRAM:ld  PROJECT:ld64-253.9
 configured to support archs: armv6 armv7 armv7s arm64 i386 x86_64 x86_64h armv6m armv7k armv7m armv7em (tvOS)
 Library search paths:
@@ -63,17 +55,13 @@
   link line regex: [^( *|.*[/\])(ld|([^/\]+-)?ld|collect2)[^/\]*( |$)]
   ignore line: [Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp]
   ignore line: []
-  ignore line: [Run Build Command:"/usr/bin/make" "cmTC_e7743/fast"]
-  ignore line: [/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_e7743.dir/build.make CMakeFiles/cmTC_e7743.dir/build]
-  ignore line: [Building C object CMakeFiles/cmTC_e7743.dir/CMakeCCompilerABI.c.o]
-  ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -o CMakeFiles/cmTC_e7743.dir/CMakeCCompilerABI.c.o   -c /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCCompilerABI.c]
-  ignore line: [Linking C executable cmTC_e7743]
-  ignore line: [/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_e7743.dir/link.txt --verbose=1]
-  ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names  -v -Wl,-v CMakeFiles/cmTC_e7743.dir/CMakeCCompilerABI.c.o  -o cmTC_e7743 ]
+  ignore line: [Run Build Command:"/usr/local/bin/ninja" "cmTC_6d9b4"]
+  ignore line: [[1/2] Building C object CMakeFiles/cmTC_6d9b4.dir/CMakeCCompilerABI.c.o]
+  ignore line: [[2/2] Linking C executable cmTC_6d9b4]
   ignore line: [Apple LLVM version 7.0.2 (clang-700.1.81)]
   ignore line: [Target: x86_64-apple-darwin15.6.0]
   ignore line: [Thread model: posix]
-  link line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -dynamic -arch x86_64 -macosx_version_min 10.11.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -o cmTC_e7743 -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_e7743.dir/CMakeCCompilerABI.c.o -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a]
+  link line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -dynamic -arch x86_64 -macosx_version_min 10.11.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -o cmTC_6d9b4 -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_6d9b4.dir/CMakeCCompilerABI.c.o -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a]
     arg [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld] ==> ignore
     arg [-demangle] ==> ignore
     arg [-dynamic] ==> ignore
@@ -84,11 +72,11 @@
     arg [-syslibroot] ==> ignore
     arg [/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk] ==> ignore
     arg [-o] ==> ignore
-    arg [cmTC_e7743] ==> ignore
+    arg [cmTC_6d9b4] ==> ignore
     arg [-search_paths_first] ==> ignore
     arg [-headerpad_max_install_names] ==> ignore
     arg [-v] ==> ignore
-    arg [CMakeFiles/cmTC_e7743.dir/CMakeCCompilerABI.c.o] ==> ignore
+    arg [CMakeFiles/cmTC_6d9b4.dir/CMakeCCompilerABI.c.o] ==> ignore
     arg [-lSystem] ==> lib [System]
     arg [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a] ==> lib [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a]
   Library search paths: [;/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk/usr/lib]
@@ -107,13 +95,9 @@
 Detecting C [-std=c11] compiler features compiled with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_0c859/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_0c859.dir/build.make CMakeFiles/cmTC_0c859.dir/build
-Building C object CMakeFiles/cmTC_0c859.dir/feature_tests.c.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -std=c11 -o CMakeFiles/cmTC_0c859.dir/feature_tests.c.o   -c /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/feature_tests.c
-Linking C executable cmTC_0c859
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_0c859.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names   CMakeFiles/cmTC_0c859.dir/feature_tests.c.o  -o cmTC_0c859 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_97f3b"
+[1/2] Building C object CMakeFiles/cmTC_97f3b.dir/feature_tests.c.o
+[2/2] Linking C executable cmTC_97f3b
 
 
     Feature record: C_FEATURE:1c_function_prototypes
@@ -125,13 +109,9 @@
 Detecting C [-std=c99] compiler features compiled with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_80902/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_80902.dir/build.make CMakeFiles/cmTC_80902.dir/build
-Building C object CMakeFiles/cmTC_80902.dir/feature_tests.c.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -std=c99 -o CMakeFiles/cmTC_80902.dir/feature_tests.c.o   -c /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/feature_tests.c
-Linking C executable cmTC_80902
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_80902.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names   CMakeFiles/cmTC_80902.dir/feature_tests.c.o  -o cmTC_80902 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_b22cb"
+[1/2] Building C object CMakeFiles/cmTC_b22cb.dir/feature_tests.c.o
+[2/2] Linking C executable cmTC_b22cb
 
 
     Feature record: C_FEATURE:1c_function_prototypes
@@ -143,13 +123,9 @@
 Detecting C [-std=c90] compiler features compiled with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_04c81/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_04c81.dir/build.make CMakeFiles/cmTC_04c81.dir/build
-Building C object CMakeFiles/cmTC_04c81.dir/feature_tests.c.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -std=c90 -o CMakeFiles/cmTC_04c81.dir/feature_tests.c.o   -c /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/feature_tests.c
-Linking C executable cmTC_04c81
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_04c81.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc   -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names   CMakeFiles/cmTC_04c81.dir/feature_tests.c.o  -o cmTC_04c81 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_950f5"
+[1/2] Building C object CMakeFiles/cmTC_950f5.dir/feature_tests.c.o
+[2/2] Linking C executable cmTC_950f5
 
 
     Feature record: C_FEATURE:1c_function_prototypes
@@ -159,29 +135,21 @@
 Determining if the CXX compiler works passed with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_31d90/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_31d90.dir/build.make CMakeFiles/cmTC_31d90.dir/build
-Building CXX object CMakeFiles/cmTC_31d90.dir/testCXXCompiler.cxx.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -o CMakeFiles/cmTC_31d90.dir/testCXXCompiler.cxx.o -c /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp/testCXXCompiler.cxx
-Linking CXX executable cmTC_31d90
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_31d90.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names   CMakeFiles/cmTC_31d90.dir/testCXXCompiler.cxx.o  -o cmTC_31d90 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_8f1dd"
+[1/2] Building CXX object CMakeFiles/cmTC_8f1dd.dir/testCXXCompiler.cxx.o
+[2/2] Linking CXX executable cmTC_8f1dd
 
 
 Detecting CXX compiler ABI info compiled with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_7b677/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_7b677.dir/build.make CMakeFiles/cmTC_7b677.dir/build
-Building CXX object CMakeFiles/cmTC_7b677.dir/CMakeCXXCompilerABI.cpp.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -o CMakeFiles/cmTC_7b677.dir/CMakeCXXCompilerABI.cpp.o -c /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCXXCompilerABI.cpp
-Linking CXX executable cmTC_7b677
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_7b677.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names  -v -Wl,-v CMakeFiles/cmTC_7b677.dir/CMakeCXXCompilerABI.cpp.o  -o cmTC_7b677 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_0e0de"
+[1/2] Building CXX object CMakeFiles/cmTC_0e0de.dir/CMakeCXXCompilerABI.cpp.o
+[2/2] Linking CXX executable cmTC_0e0de
 Apple LLVM version 7.0.2 (clang-700.1.81)
 Target: x86_64-apple-darwin15.6.0
 Thread model: posix
- "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -dynamic -arch x86_64 -macosx_version_min 10.11.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -o cmTC_7b677 -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_7b677.dir/CMakeCXXCompilerABI.cpp.o -lc++ -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a
+ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -dynamic -arch x86_64 -macosx_version_min 10.11.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -o cmTC_0e0de -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_0e0de.dir/CMakeCXXCompilerABI.cpp.o -lc++ -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a
 @(#)PROGRAM:ld  PROJECT:ld64-253.9
 configured to support archs: armv6 armv7 armv7s arm64 i386 x86_64 x86_64h armv6m armv7k armv7m armv7em (tvOS)
 Library search paths:
@@ -194,17 +162,13 @@
   link line regex: [^( *|.*[/\])(ld|([^/\]+-)?ld|collect2)[^/\]*( |$)]
   ignore line: [Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp]
   ignore line: []
-  ignore line: [Run Build Command:"/usr/bin/make" "cmTC_7b677/fast"]
-  ignore line: [/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_7b677.dir/build.make CMakeFiles/cmTC_7b677.dir/build]
-  ignore line: [Building CXX object CMakeFiles/cmTC_7b677.dir/CMakeCXXCompilerABI.cpp.o]
-  ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -o CMakeFiles/cmTC_7b677.dir/CMakeCXXCompilerABI.cpp.o -c /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCXXCompilerABI.cpp]
-  ignore line: [Linking CXX executable cmTC_7b677]
-  ignore line: [/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_7b677.dir/link.txt --verbose=1]
-  ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names  -v -Wl,-v CMakeFiles/cmTC_7b677.dir/CMakeCXXCompilerABI.cpp.o  -o cmTC_7b677 ]
+  ignore line: [Run Build Command:"/usr/local/bin/ninja" "cmTC_0e0de"]
+  ignore line: [[1/2] Building CXX object CMakeFiles/cmTC_0e0de.dir/CMakeCXXCompilerABI.cpp.o]
+  ignore line: [[2/2] Linking CXX executable cmTC_0e0de]
   ignore line: [Apple LLVM version 7.0.2 (clang-700.1.81)]
   ignore line: [Target: x86_64-apple-darwin15.6.0]
   ignore line: [Thread model: posix]
-  link line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -dynamic -arch x86_64 -macosx_version_min 10.11.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -o cmTC_7b677 -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_7b677.dir/CMakeCXXCompilerABI.cpp.o -lc++ -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a]
+  link line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -dynamic -arch x86_64 -macosx_version_min 10.11.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -o cmTC_0e0de -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_0e0de.dir/CMakeCXXCompilerABI.cpp.o -lc++ -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a]
     arg [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld] ==> ignore
     arg [-demangle] ==> ignore
     arg [-dynamic] ==> ignore
@@ -215,11 +179,11 @@
     arg [-syslibroot] ==> ignore
     arg [/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk] ==> ignore
     arg [-o] ==> ignore
-    arg [cmTC_7b677] ==> ignore
+    arg [cmTC_0e0de] ==> ignore
     arg [-search_paths_first] ==> ignore
     arg [-headerpad_max_install_names] ==> ignore
     arg [-v] ==> ignore
-    arg [CMakeFiles/cmTC_7b677.dir/CMakeCXXCompilerABI.cpp.o] ==> ignore
+    arg [CMakeFiles/cmTC_0e0de.dir/CMakeCXXCompilerABI.cpp.o] ==> ignore
     arg [-lc++] ==> lib [c++]
     arg [-lSystem] ==> lib [System]
     arg [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a] ==> lib [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../lib/clang/7.0.2/lib/darwin/libclang_rt.osx.a]
@@ -239,13 +203,9 @@
 Detecting CXX [-std=c++1z] compiler features compiled with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_243bf/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_243bf.dir/build.make CMakeFiles/cmTC_243bf.dir/build
-Building CXX object CMakeFiles/cmTC_243bf.dir/feature_tests.cxx.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -std=c++1z -o CMakeFiles/cmTC_243bf.dir/feature_tests.cxx.o -c /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/feature_tests.cxx
-Linking CXX executable cmTC_243bf
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_243bf.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names   CMakeFiles/cmTC_243bf.dir/feature_tests.cxx.o  -o cmTC_243bf 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_2fc56"
+[1/2] Building CXX object CMakeFiles/cmTC_2fc56.dir/feature_tests.cxx.o
+[2/2] Linking CXX executable cmTC_2fc56
 
 
     Feature record: CXX_FEATURE:1cxx_aggregate_default_initializers
@@ -310,13 +270,9 @@
 Detecting CXX [-std=c++14] compiler features compiled with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_256cb/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_256cb.dir/build.make CMakeFiles/cmTC_256cb.dir/build
-Building CXX object CMakeFiles/cmTC_256cb.dir/feature_tests.cxx.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -std=c++14 -o CMakeFiles/cmTC_256cb.dir/feature_tests.cxx.o -c /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/feature_tests.cxx
-Linking CXX executable cmTC_256cb
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_256cb.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names   CMakeFiles/cmTC_256cb.dir/feature_tests.cxx.o  -o cmTC_256cb 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_8c7c8"
+[1/2] Building CXX object CMakeFiles/cmTC_8c7c8.dir/feature_tests.cxx.o
+[2/2] Linking CXX executable cmTC_8c7c8
 
 
     Feature record: CXX_FEATURE:1cxx_aggregate_default_initializers
@@ -381,13 +337,9 @@
 Detecting CXX [-std=c++11] compiler features compiled with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_e2e29/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_e2e29.dir/build.make CMakeFiles/cmTC_e2e29.dir/build
-Building CXX object CMakeFiles/cmTC_e2e29.dir/feature_tests.cxx.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -std=c++11 -o CMakeFiles/cmTC_e2e29.dir/feature_tests.cxx.o -c /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/feature_tests.cxx
-Linking CXX executable cmTC_e2e29
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_e2e29.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names   CMakeFiles/cmTC_e2e29.dir/feature_tests.cxx.o  -o cmTC_e2e29 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_33eb5"
+[1/2] Building CXX object CMakeFiles/cmTC_33eb5.dir/feature_tests.cxx.o
+[2/2] Linking CXX executable cmTC_33eb5
 
 
     Feature record: CXX_FEATURE:0cxx_aggregate_default_initializers
@@ -452,13 +404,9 @@
 Detecting CXX [-std=c++98] compiler features compiled with the following output:
 Change Dir: /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/CMakeTmp
 
-Run Build Command:"/usr/bin/make" "cmTC_2dc1c/fast"
-/Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_2dc1c.dir/build.make CMakeFiles/cmTC_2dc1c.dir/build
-Building CXX object CMakeFiles/cmTC_2dc1c.dir/feature_tests.cxx.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk   -std=c++98 -o CMakeFiles/cmTC_2dc1c.dir/feature_tests.cxx.o -c /Users/e135704/seminar/osc/ikkun-osc/sample/CMakeFiles/feature_tests.cxx
-Linking CXX executable cmTC_2dc1c
-/usr/local/Cellar/cmake/3.8.2/bin/cmake -E cmake_link_script CMakeFiles/cmTC_2dc1c.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++    -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names   CMakeFiles/cmTC_2dc1c.dir/feature_tests.cxx.o  -o cmTC_2dc1c 
+Run Build Command:"/usr/local/bin/ninja" "cmTC_ddddf"
+[1/2] Building CXX object CMakeFiles/cmTC_ddddf.dir/feature_tests.cxx.o
+[2/2] Linking CXX executable cmTC_ddddf
 
 
     Feature record: CXX_FEATURE:0cxx_aggregate_default_initializers
--- a/sample/build.ninja	Fri Jun 16 05:31:42 2017 +0900
+++ b/sample/build.ninja	Fri Jun 16 20:10:06 2017 +0900
@@ -56,6 +56,8 @@
   FLAGS = -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk
   OBJECT_DIR = CMakeFiles/hello.dir
   OBJECT_FILE_DIR = CMakeFiles/hello.dir
+  TARGET_COMPILE_PDB = CMakeFiles/hello.dir/
+  TARGET_PDB = hello.pdb
 
 # =============================================================================
 # Link build statements for EXECUTABLE target hello
@@ -69,8 +71,9 @@
   OBJECT_DIR = CMakeFiles/hello.dir
   POST_BUILD = :
   PRE_LINK = :
+  TARGET_COMPILE_PDB = CMakeFiles/hello.dir/
   TARGET_FILE = hello
-  TARGET_PDB = hello.dbg
+  TARGET_PDB = hello.pdb
 # =============================================================================
 # Target aliases.
 
@@ -100,13 +103,13 @@
 #############################################
 # Re-run CMake if any of its inputs changed.
 
-build build.ninja: RERUN_CMAKE | /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCXXInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCommonLanguageInclude.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeGenericSystem.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeLanguageInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeSystemSpecificInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeSystemSpecificInitialize.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Clang.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/GNU.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-AppleClang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-AppleClang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Initialize.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/UnixPaths.cmake CMakeCache.txt CMakeFiles/3.8.2/CMakeCCompiler.cmake CMakeFiles/3.8.2/CMakeCXXCompiler.cmake CMakeFiles/3.8.2/CMakeSystem.cmake CMakeLists.txt
+build build.ninja: RERUN_CMAKE | /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCCompiler.cmake.in /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCCompilerABI.c /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCXXCompiler.cmake.in /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCXXCompilerABI.cpp /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCXXInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCommonLanguageInclude.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCompilerIdDetection.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCXXCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCompileFeatures.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCompilerABI.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCompilerId.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineSystem.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeFindBinUtils.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeGenericSystem.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeLanguageInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeNinjaFindMake.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeParseImplicitLinkInfo.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeSystem.cmake.in /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeSystemSpecificInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeSystemSpecificInitialize.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeTestCCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeTestCXXCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeTestCompilerCommon.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/ADSP-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/ARMCC-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-C-FeatureTests.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-CXX-FeatureTests.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Borland-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Bruce-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Clang-CXX-TestableFeatures.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Clang-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Clang-DetermineCompilerInternal.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Clang.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Comeau-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Compaq-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Compaq-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Cray-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Embarcadero-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Fujitsu-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/GHS-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/GNU-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/GNU-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/GNU.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/HP-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/HP-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/IAR-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/IBMCPP-C-DetermineVersionInternal.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/IBMCPP-CXX-DetermineVersionInternal.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Intel-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/MIPSpro-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/MSVC-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/NVIDIA-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/OpenWatcom-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/PGI-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/PathScale-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/SCO-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/SDCC-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/SunPro-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/SunPro-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/TI-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/TinyCC-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/VisualAge-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/VisualAge-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Watcom-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/XL-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/XL-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/zOS-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/zOS-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Internal/FeatureTesting.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-AppleClang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-AppleClang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Determine-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Initialize.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/UnixPaths.cmake CMakeCache.txt CMakeFiles/3.8.2/CMakeCCompiler.cmake CMakeFiles/3.8.2/CMakeCXXCompiler.cmake CMakeFiles/3.8.2/CMakeSystem.cmake CMakeFiles/feature_tests.c CMakeFiles/feature_tests.cxx CMakeLists.txt
   pool = console
 
 #############################################
 # A missing CMake input file is not an error.
 
-build /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCXXInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCommonLanguageInclude.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeGenericSystem.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeLanguageInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeSystemSpecificInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeSystemSpecificInitialize.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Clang.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/GNU.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-AppleClang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-AppleClang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Initialize.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/UnixPaths.cmake CMakeCache.txt CMakeFiles/3.8.2/CMakeCCompiler.cmake CMakeFiles/3.8.2/CMakeCXXCompiler.cmake CMakeFiles/3.8.2/CMakeSystem.cmake CMakeLists.txt: phony
+build /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCCompiler.cmake.in /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCCompilerABI.c /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCXXCompiler.cmake.in /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCXXCompilerABI.cpp /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCXXInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCommonLanguageInclude.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeCompilerIdDetection.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCXXCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCompileFeatures.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCompilerABI.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineCompilerId.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeDetermineSystem.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeFindBinUtils.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeGenericSystem.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeLanguageInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeNinjaFindMake.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeParseImplicitLinkInfo.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeSystem.cmake.in /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeSystemSpecificInformation.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeSystemSpecificInitialize.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeTestCCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeTestCXXCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/CMakeTestCompilerCommon.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/ADSP-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/ARMCC-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-C-FeatureTests.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-CXX-FeatureTests.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/AppleClang-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Borland-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Bruce-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Clang-CXX-TestableFeatures.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Clang-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Clang-DetermineCompilerInternal.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Clang.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Comeau-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Compaq-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Compaq-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Cray-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Embarcadero-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Fujitsu-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/GHS-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/GNU-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/GNU-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/GNU.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/HP-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/HP-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/IAR-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/IBMCPP-C-DetermineVersionInternal.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/IBMCPP-CXX-DetermineVersionInternal.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Intel-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/MIPSpro-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/MSVC-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/NVIDIA-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/OpenWatcom-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/PGI-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/PathScale-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/SCO-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/SDCC-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/SunPro-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/SunPro-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/TI-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/TinyCC-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/VisualAge-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/VisualAge-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/Watcom-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/XL-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/XL-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/zOS-C-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Compiler/zOS-CXX-DetermineCompiler.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Internal/FeatureTesting.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-AppleClang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-AppleClang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang-C.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Clang.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Determine-CXX.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin-Initialize.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/Darwin.cmake /usr/local/Cellar/cmake/3.8.2/share/cmake/Modules/Platform/UnixPaths.cmake CMakeCache.txt CMakeFiles/3.8.2/CMakeCCompiler.cmake CMakeFiles/3.8.2/CMakeCXXCompiler.cmake CMakeFiles/3.8.2/CMakeSystem.cmake CMakeFiles/feature_tests.c CMakeFiles/feature_tests.cxx CMakeLists.txt: phony
 
 #############################################
 # Clean all the built files.
--- a/sample2/CMakeLists.txt	Fri Jun 16 05:31:42 2017 +0900
+++ b/sample2/CMakeLists.txt	Fri Jun 16 20:10:06 2017 +0900
@@ -1,6 +1,5 @@
 cmake_minimum_required(VERSION 3.7)
 find_package(CUDA REQUIRED)
 include_directories(/Developer/NVIDIA/CUDA-8.0/samples/common/inc)
-cuda_add_executable(hello hello.cu)
 cuda_add_executable(matrixMul matrixMul.cu)
--- a/sample/cmake_install.cmake	Fri Jun 16 05:31:42 2017 +0900
+++ b/sample/cmake_install.cmake	Fri Jun 16 20:10:06 2017 +0900
@@ -1,4 +1,4 @@
 # Install script for directory: /Users/one/hg/Papers/2017/ikkun-osc/sample
 
 # Set the install prefix
 if(NOT DEFINED CMAKE_INSTALL_PREFIX)
@@ -35,5 +35,5 @@
 
 string(REPLACE ";" "\n" CMAKE_INSTALL_MANIFEST_CONTENT
        "${CMAKE_INSTALL_MANIFEST_FILES}")
-file(WRITE "/Users/one/hg/Papers/2017/ikkun-osc/sample/${CMAKE_INSTALL_MANIFEST}"
+file(WRITE "/Users/e135704/seminar/osc/ikkun-osc/sample/${CMAKE_INSTALL_MANIFEST}"
      "${CMAKE_INSTALL_MANIFEST_CONTENT}")
@@ -1,4 +1,4 @@
-# Install script for directory: /Users/one/hg/Papers/2017/ikkun-osc/sample
+# Install script for directory: /Users/e135704/seminar/osc/ikkun-osc/sample
 
 # Set the install prefix
Binary file sample/hello has changed